<template>
  <div class="mobile-team-member-calendar">
    <van-nav-bar title="本人排班查询" left-arrow @click-left="$router.go(-1)">
      <template #right>
        <van-icon name="arrow-left" color="#1989fa" @click.stop="monthChange(1)" />
        <span>{{ moment(date).format('YYYY - MM') }}</span>
        <van-icon name="arrow" color="#1989fa" @click.stop="monthChange(-1)" />
      </template>
    </van-nav-bar>

    <van-calendar :poppable="false" :default-date="new Date(2010, 5, 1)" :show-confirm="false" :show-title="false"
      :show-subtitle="false" :min-date="minDate" :max-date="maxDate" color="#1989fa" :row-height="112" readonly>
      <template v-slot:top-info="day">
        <div class="top-info">
          <van-tag v-if="getWorkTime(day).length" plain type="success">
            已排班
          </van-tag>
          <van-tag v-else plain type="warning">未排班</van-tag>
        </div>
      </template>
      <template v-slot:bottom-info="day">
        <div class="bottom-info">
          <van-tag v-for="item in getWorkTime(day)" :key="item.id" plain type="primary">
            {{ item.cmgtDutyWorkclass.scheduleStart }}
            <br />
            {{ item.cmgtDutyWorkclass.duringTime }}
          </van-tag>
        </div>
      </template>
    </van-calendar>
  </div>
</template>

<script>
import moment from 'moment'
import CmgtDutyWorkarrangeApi from '@/views/Manage/duty/api/CmgtDutyWorkarrangeApi'

const { findPersonArrange } = CmgtDutyWorkarrangeApi

export default {
  name: 'MobileTeamMemberCalendar',
  data() {
    return {
      schedulingData: [],// 排班信息
      date: `${moment().format('YYYY-MM')}`,
      minDate: new Date(),
      maxDate: new Date(),
      loading: true,
      userInfo: null
    }
  },
  created() {
    this.getSchedulingData()
  },
  methods: {
    moment,
    // 获得排班时间
    getWorkTime({ date }) {
      return this.schedulingData?.filter(i => i.arrangeDate === moment(date).format('YYYY-MM-DD')) || []
    },

    // 月份切换
    monthChange(val) {
      this.loading = true
      const standardTime = moment(new Date(this.date)).subtract(val, 'months')
      this.date = `${standardTime.format('YYYY-MM')}`
      const maxDate = standardTime.endOf('month').format('YYYY-MM-DD')
      // 获取切换月份的排班信息后再切换显示的月份
      this.getSchedulingData(_ => {
        this.minDate = new Date(`${this.date}-01`)
        this.maxDate = new Date(maxDate)
      })
    },

    // 获取排班信息
    async getSchedulingData(callback) {
      try {
        let data = this.$store.state.user.currentUserDetail?.user || null
        if (data) {
          let queryData = {
            date: `${this.date}-01`,
            phone: data.mobile
          }
          const { data: { value } } = await findPersonArrange(queryData)
          this.schedulingData = value
        } else {
          this.$store.dispatch('user/loadCurrentUserDetail').then(async res => {
            this.userInfo = this.$store.state.user.currentUserDetail?.user
            let queryData = {
              date: `${this.date}-01`,
              phone: this.userInfo.mobile
            }
            const { data: { value } } = await findPersonArrange(queryData)
            this.schedulingData = value
          })
        }
      } finally {
        callback && callback()
        this.loading = false
      }
    }
  }
}
</script>

<style scoped lang="scss">
.mobile-team-member-calendar {
  height: 100%;

  ::v-deep .van-nav-bar__right {
    display: flex;
    padding: 0 2Px 0 0;

    span {
      font-size: 65px;
    }

    .van-icon {
      font-size: 85px !important;
      padding: 20px 20px 20px 20px;
    }
  }

  ::v-deep .van-calendar {
    height: calc(100% - 46Px);

    .van-calendar__month-title {
      display: none;
    }

    .van-calendar__body {
      padding-top: 50px;

      .van-calendar__day {
        display: flex;
        flex-direction: column;
        justify-content: flex-start;
        row-gap: 20px;
        border: 1px solid #ebeef5;
        box-sizing: border-box;
        padding: 20px 0;

        >div {
          position: static;
        }
      }
    }

  }
}
</style>
